//! # Cleanup thread
//!
//! This module manage a thread that automatically delete old data
//!
//! @author Pierre Hubert

use crate::constants::CLEAN_UP_INTERVAL;
use crate::data::error::Res;
use crate::helpers::account_helper;

/// Start the maintenance thread
pub fn start() -> Res {
    std::thread::spawn(clean_up_thread_handler);
    Ok(())
}

/// Clean up thread handler
fn clean_up_thread_handler() {
    loop {
        println!("Start clean up operation");
        match do_clean() {
            Ok(_) => {
                println!("Clean thread executed successfully!");
            }

            Err(e) => {
                eprintln!("Failed to clean data! {:#?}", e);
            }
        }

        std::thread::sleep(CLEAN_UP_INTERVAL);
    }
}

/// Do the cleanup
fn do_clean() -> Res {

    // Clean old login tokens
    account_helper::clean_up_old_access_tokens()?;

    Ok(())
}